## Checklist

- [ ] I've formatted the new code by running `hatch run dev:format` before committing.
- [ ] I've added tests for new code.
- [ ] I've added docstrings for the new code.

## Description

Please describe your changes here. If this fixes a bug, please link to the issue, if possible.

Issue Number: N/A
